@@ -1,22 +1,14 @@
+
 import os
-import glob
 import xml.etree.ElementTree as ET
 
-from firstimpression.constants import APIS, TEMP_FOLDER, LOCAL_INTEGRATED_FOLDER
-from firstimpression.api.request import request
-from firstimpression.file import update_directories_api, check_too_old, write_root_to_xml_files
-from firstimpression.scala import variables, Log
-
-##################################################################################################
-# LOGGING
-##################################################################################################
-
-script = 'Solaredge'
-
-info = Log('INFO', script)
-debug = Log('DEBUG', script)
-warn = Log('WARN', script)
-error = Log('ERROR', script)
+from firstimpression.api.request import give_error_message, request
+from firstimpression.constants import APIS
+from firstimpression.file import (check_too_old, create_directories,
+                                  purge_directories)
+from firstimpression.placeholder import update_placeholders
+from firstimpression.scala import ScalaPlayer
+from requests.models import Response
 
 ##################################################################################################
 # CONSTANTS
@@ -25,37 +17,49 @@ error = Log('ERROR', script)
 NAME = APIS['solaredge']
 URL = 'https://monitoringpublic.solaredge.com/solaredge-web/p/kiosk/kioskData?locale=nl_NL'
 
-XML_TEMP_PATH = os.path.join(TEMP_FOLDER, NAME, 'data.xml')
-XML_LOCAL_PATH = os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, 'data*.xml')
+XML_FILENAME = 'data.xml'
 
 MAX_FILE_AGE = 60 * 5
 
+##################################################################################################
+# Scala Player
+##################################################################################################
+
+scala = ScalaPlayer(NAME)
+
+XML_TEMP_PATH = os.path.join(scala.temp_folder, XML_FILENAME)
 
 
 ##################################################################################################
 # MAIN FUNCTIONS API
 ##################################################################################################
 
-def run_api(guid):
+def run_api():
 
-    debug.log('folder name: {}'.format(NAME))
-    debug.log('guid: {}'.format(guid))
+    guid = scala.variables['guid']
 
-    update_directories_api(NAME)
+    scala.debug('folder name: {}'.format(NAME))
+    scala.debug('guid: {}'.format(guid))
+
+    create_directories([scala.temp_folder, scala.content_folder])
+    purge_directories([scala.temp_folder, scala.content_folder], max_days=1)
+    update_placeholders()
 
     if check_too_old(XML_TEMP_PATH, MAX_FILE_AGE):
 
         root = ET.Element("root")
 
-        response, is_error = request(URL, params={'guid':guid}, method='post')
+        response = request(URL, params={'guid': guid}, method='post')
 
-        if is_error:
+        if not isinstance(response, Response):
+            message = give_error_message(response)
             if response['type'] == 'ERROR':
-                error.log('request {} -> {}'.format(response['reason'], response['message']))
+                scala.error(message)
             elif response['type'] == 'WARN':
-                warn.log('request {} -> {}'.format(response['reason'], response['message']))
-            exit()
-        
+                scala.warn(message)
+
+            raise SystemExit
+
         response = response.text.split('\n')
 
         co2_saved = ''
@@ -64,9 +68,11 @@ def run_api(guid):
 
         for elem in response:
             if 'CO2EmissionSaved' in elem:
-                co2_saved = '{:,}'.format(int(round(float(elem.split(':')[1].split(' ')[0][1:].replace('.', '').replace(',','.')),0))).replace(',', '.') + ' kg'
+                co2_saved = '{:,}'.format(int(round(float(elem.split(':')[1].split(
+                    ' ')[0][1:].replace('.', '').replace(',', '.')), 0))).replace(',', '.') + ' kg'
             if 'treesEquivalentSaved' in elem:
-                trees_saved = '{:,}'.format(int(round(float(elem.split(':')[1][1:-3].replace('.', '').replace(',','.')),0))).replace(',', '.')
+                trees_saved = '{:,}'.format(int(round(float(elem.split(
+                    ':')[1][1:-3].replace('.', '').replace(',', '.')), 0))).replace(',', '.')
             if 'lastDayEnergy' in elem:
                 last_day_energy = elem.split(':')[1][1:-3]
 
@@ -74,29 +80,23 @@ def run_api(guid):
         ET.SubElement(root, "TreesSaved").text = trees_saved
         ET.SubElement(root, "EnergyToday").text = last_day_energy
 
-        write_root_to_xml_files(root, XML_TEMP_PATH, NAME)
+        temp_path = scala.download_root_temp(root, XML_FILENAME)
+        scala.install_content(temp_path)
     else:
-        debug.log('File not old enough to update')
+        scala.debug('File not old enough to update')
+
 
 def check_api():
-    svars = variables()
+    svars = scala.variables
 
-    file_path = sorted(glob.glob(XML_LOCAL_PATH))
+    file_path = scala.find_content(
+        'Content://{}/{}'.format(NAME, XML_FILENAME))
 
-    if len(file_path) > 0:
-        file_path = file_path[-1]
-        debug.log('glob filepath: {}'.format(file_path))
-
-        if check_too_old(file_path, MAX_FILE_AGE*2):
-            svars['skipscript'] = True
-            info.log('file too old')
-        else:
-            svars['skipscript'] = False
-    else:
-        warn.log('File does not exists')
+    if check_too_old(file_path, MAX_FILE_AGE*2):
         svars['skipscript'] = True
-
-    
+        scala.debug('file too old')
+    else:
+        svars['skipscript'] = False
 
 
 ##################################################################################################
@@ -111,4 +111,4 @@ def check_api():
 
 ##################################################################################################
 # PARSE FUNCTIONS
-##################################################################################################
\ No newline at end of file
+##################################################################################################
